#define MOZ_SOURCE_STAMP 120111e65bc4e9b99da97e9d046765de95fbac8c
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-esr52
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-esr52/rev/120111e65bc4e9b99da97e9d046765de95fbac8c
